Documentation
¶
Overview ¶
Package comet wraps the CometBFT RPC client with the specific calls cometcli tools need.
Index ¶
- type Client
- func (c *Client) ABCIInfo(ctx context.Context) (*coretypes.ResultABCIInfo, error)
- func (c *Client) AllValidators(ctx context.Context, height *int64) ([]*ctypes.Validator, error)
- func (c *Client) Block(ctx context.Context, height *int64) (*coretypes.ResultBlock, error)
- func (c *Client) BlockResults(ctx context.Context, height *int64) (*coretypes.ResultBlockResults, error)
- func (c *Client) Commit(ctx context.Context, height *int64) (*coretypes.ResultCommit, error)
- func (c *Client) DumpConsensusState(ctx context.Context) (*coretypes.ResultDumpConsensusState, error)
- func (c *Client) Health(ctx context.Context) error
- func (c *Client) NetInfo(ctx context.Context) (*coretypes.ResultNetInfo, error)
- func (c *Client) Status(ctx context.Context) (*coretypes.ResultStatus, error)
- func (c *Client) Validators(ctx context.Context, height *int64, page, perPage int) (*coretypes.ResultValidators, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is a thin wrapper over the cometbft RPC HTTP client.
func (*Client) AllValidators ¶
AllValidators collects the full set across pages.
func (*Client) BlockResults ¶
func (*Client) Commit ¶
Commit returns the signed commit at a height — used to count which validators signed a given block (missed-block tracking).
func (*Client) DumpConsensusState ¶
func (*Client) Validators ¶
func (c *Client) Validators(ctx context.Context, height *int64, page, perPage int) (*coretypes.ResultValidators, error)
Validators returns the validator set at a height (paginated).
Click to show internal directories.
Click to hide internal directories.